# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/intraday_analytics/v1/intraday_sma.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2
from systemathics.apis.type.shared.v1 import sampling_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_sampling__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='systemathics/apis/services/intraday_analytics/v1/intraday_sma.proto',
  package='systemathics.apis.services.intraday_analytics.v1',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nCsystemathics/apis/services/intraday_analytics/v1/intraday_sma.proto\x12\x30systemathics.apis.services.intraday_analytics.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\x1a/systemathics/apis/type/shared/v1/sampling.proto\"\xfc\x01\n\x12IntradaySmaRequest\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12<\n\x08sampling\x18\x02 \x01(\x0e\x32*.systemathics.apis.type.shared.v1.Sampling\x12\x42\n\x0b\x63onstraints\x18\x03 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.Constraints\x12\x0e\n\x06length\x18\x04 \x01(\x05\x12\x12\n\nadjustment\x18\x05 \x01(\x08\"f\n\x13IntradaySmaResponse\x12O\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x41.systemathics.apis.services.intraday_analytics.v1.IntradaySmaData\"\x7f\n\x0fIntradaySmaData\x12.\n\ntime_stamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05value\x18\x02 \x01(\x01\x12-\n\x07\x61verage\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue2\xb1\x01\n\x12IntradaySmaService\x12\x9a\x01\n\x0bIntradaySma\x12\x44.systemathics.apis.services.intraday_analytics.v1.IntradaySmaRequest\x1a\x45.systemathics.apis.services.intraday_analytics.v1.IntradaySmaResponseb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_sampling__pb2.DESCRIPTOR,])




_INTRADAYSMAREQUEST = _descriptor.Descriptor(
  name='IntradaySmaRequest',
  full_name='systemathics.apis.services.intraday_analytics.v1.IntradaySmaRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='systemathics.apis.services.intraday_analytics.v1.IntradaySmaRequest.identifier', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sampling', full_name='systemathics.apis.services.intraday_analytics.v1.IntradaySmaRequest.sampling', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='constraints', full_name='systemathics.apis.services.intraday_analytics.v1.IntradaySmaRequest.constraints', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='length', full_name='systemathics.apis.services.intraday_analytics.v1.IntradaySmaRequest.length', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adjustment', full_name='systemathics.apis.services.intraday_analytics.v1.IntradaySmaRequest.adjustment', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=339,
  serialized_end=591,
)


_INTRADAYSMARESPONSE = _descriptor.Descriptor(
  name='IntradaySmaResponse',
  full_name='systemathics.apis.services.intraday_analytics.v1.IntradaySmaResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='systemathics.apis.services.intraday_analytics.v1.IntradaySmaResponse.data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=593,
  serialized_end=695,
)


_INTRADAYSMADATA = _descriptor.Descriptor(
  name='IntradaySmaData',
  full_name='systemathics.apis.services.intraday_analytics.v1.IntradaySmaData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='systemathics.apis.services.intraday_analytics.v1.IntradaySmaData.time_stamp', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='systemathics.apis.services.intraday_analytics.v1.IntradaySmaData.value', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='average', full_name='systemathics.apis.services.intraday_analytics.v1.IntradaySmaData.average', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=697,
  serialized_end=824,
)

_INTRADAYSMAREQUEST.fields_by_name['identifier'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2._IDENTIFIER
_INTRADAYSMAREQUEST.fields_by_name['sampling'].enum_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_sampling__pb2._SAMPLING
_INTRADAYSMAREQUEST.fields_by_name['constraints'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2._CONSTRAINTS
_INTRADAYSMARESPONSE.fields_by_name['data'].message_type = _INTRADAYSMADATA
_INTRADAYSMADATA.fields_by_name['time_stamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_INTRADAYSMADATA.fields_by_name['average'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
DESCRIPTOR.message_types_by_name['IntradaySmaRequest'] = _INTRADAYSMAREQUEST
DESCRIPTOR.message_types_by_name['IntradaySmaResponse'] = _INTRADAYSMARESPONSE
DESCRIPTOR.message_types_by_name['IntradaySmaData'] = _INTRADAYSMADATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

IntradaySmaRequest = _reflection.GeneratedProtocolMessageType('IntradaySmaRequest', (_message.Message,), {
  'DESCRIPTOR' : _INTRADAYSMAREQUEST,
  '__module__' : 'systemathics.apis.services.intraday_analytics.v1.intraday_sma_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.intraday_analytics.v1.IntradaySmaRequest)
  })
_sym_db.RegisterMessage(IntradaySmaRequest)

IntradaySmaResponse = _reflection.GeneratedProtocolMessageType('IntradaySmaResponse', (_message.Message,), {
  'DESCRIPTOR' : _INTRADAYSMARESPONSE,
  '__module__' : 'systemathics.apis.services.intraday_analytics.v1.intraday_sma_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.intraday_analytics.v1.IntradaySmaResponse)
  })
_sym_db.RegisterMessage(IntradaySmaResponse)

IntradaySmaData = _reflection.GeneratedProtocolMessageType('IntradaySmaData', (_message.Message,), {
  'DESCRIPTOR' : _INTRADAYSMADATA,
  '__module__' : 'systemathics.apis.services.intraday_analytics.v1.intraday_sma_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.intraday_analytics.v1.IntradaySmaData)
  })
_sym_db.RegisterMessage(IntradaySmaData)



_INTRADAYSMASERVICE = _descriptor.ServiceDescriptor(
  name='IntradaySmaService',
  full_name='systemathics.apis.services.intraday_analytics.v1.IntradaySmaService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=827,
  serialized_end=1004,
  methods=[
  _descriptor.MethodDescriptor(
    name='IntradaySma',
    full_name='systemathics.apis.services.intraday_analytics.v1.IntradaySmaService.IntradaySma',
    index=0,
    containing_service=None,
    input_type=_INTRADAYSMAREQUEST,
    output_type=_INTRADAYSMARESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_INTRADAYSMASERVICE)

DESCRIPTOR.services_by_name['IntradaySmaService'] = _INTRADAYSMASERVICE

# @@protoc_insertion_point(module_scope)
